import mock
import unittest
import tempfile
import shutil
import os
from testing import venv
from ucitests import fixtures


class TestVirtualEnv(unittest.TestCase):
    def setUp(self):
        super(TestVirtualEnv, self).setUp()
        self.tempdir = tempfile.mkdtemp()
        self.addCleanup(shutil.rmtree, self.tempdir)
        _p = mock.patch('testing.venv.get_basedir',
                        return_value=self.tempdir)
        _p.start()
        self.addCleanup(_p.stop)
        override = {
            'PATH': os.environ.get('PATH', ''),
            'PYTHONPATH': os.environ.get('PYTHONPATH', ''),
            'VIRTUAL_ENV': os.environ.get('VIRTUAL_ENV', ''),
            'PIP_CACHE': os.environ.get('PIP_CACHE', ''),
            'REEXECED_UNDER_VENV': os.environ.get('REXECED_UNDER_VENV', ''),
            'CI_DEPS_BRANCH': os.environ.get('CI_DEPS_BRANCH', ''),
            'ARCHFLAGS': os.environ.get('ARCHFLAGS', ''),
        }
        fixtures.isolate_from_env(self, override)

    def test_create(self):
        name = tempfile.mktemp()
        venv.create(name)
        activate = os.path.join(self.tempdir, name, 'bin/activate')
        self.assertTrue(os.path.exists(activate))

    def test_find_components(self):
        components = [x for x in venv.find_components()]
        self.assertTrue('ci-utils' in components)

    def test_prepare(self):
        name = tempfile.mktemp()
        venv.create(name, 'python2.7')
        venv.prepare(['ci-utils'])
        pkgs = 'lib/python2.7/site-packages'
        pkgs = os.path.join(self.tempdir, name, pkgs)
        self.assertTrue(os.path.exists(pkgs))


if __name__ == '__main__':
    unittest.main()
